@@ -178,13 +178,21 @@ impl Music {
     }
 }
 
+#[derive(Deserialize, Debug, Clone)]
+#[serde(untagged)]
+pub enum PlayerName {
+    PlayerName(String),
+    PlayerNames(Vec<String>),
+}
+
 #[derive(Deserialize, Debug, Clone)]
 #[serde(deny_unknown_fields, default)]
 pub struct MusicConfig {
-    /// Name of the music player. Must be the same name the player is
-    /// registered with the MediaPlayer2 Interface. If not specified then
+    /// Name(s) of the music player(s). Must be the same name the player is
+    /// registered with the MediaPlayer2 Interface. This can be either a single
+    /// player name or an array of player names. If not specified then
     /// the block will track all players found.
-    pub player: Option<String>,
+    pub player: Option<PlayerName>,
 
     /// Max width of the block in characters, not including the buttons.
     pub max_width: usize,
@@ -287,13 +295,19 @@ impl ConfigBlock for Music {
                 500,
             )
             .unwrap();
+
+        let mut preferred_players = Vec::new();
+
+        if let Some(player) = block_config.player {
+            match player {
+                PlayerName::PlayerName(player) => preferred_players.push(player),
+                PlayerName::PlayerNames(players) => preferred_players = players,
+            }
+        }
+
         let names = list_names.get1::<Array<&str, _>>().unwrap().filter(|name| {
             // If an interface matches an exclude pattern, ignore it
-            !ignored_player(
-                name,
-                &interface_name_exclude_regexps,
-                block_config.player.clone(),
-            )
+            !ignored_player(name, &interface_name_exclude_regexps, &preferred_players)
         });
 
         let mut players = Vec::<Player>::new();
@@ -326,7 +340,6 @@ impl ConfigBlock for Music {
         let players = Arc::new(Mutex::new(players));
         let players_clone = players.clone();
         let send_clone = send.clone();
-        let preferred_player = block_config.player.clone();
 
         thread::Builder::new()
             .name("music".into())
@@ -393,7 +406,7 @@ impl ConfigBlock for Music {
                                 match (old_owner, new_owner) {
                                     ("", new_owner) => { // Add a new player
                                         // Skip if already presented (or ignored)
-                                        if !players.iter().any(|p| p.bus_name == new_owner) && !ignored_player(name, &interface_name_exclude_regexps, preferred_player.clone()) {
+                                        if !players.iter().any(|p| p.bus_name == new_owner) && !ignored_player(name, &interface_name_exclude_regexps, &preferred_players) {
                                             players.push(Player::new(&dbus_conn,name,new_owner));
                                             updated = true;
                                         }
@@ -781,13 +794,17 @@ fn extract_from_metadata(metadata: &dyn RefArg) -> Result<(Option<String>, Optio
 fn ignored_player(
     name: &str,
     interface_name_exclude_regexps: &[Regex],
-    preferred_player: Option<String>,
+    preferred_players: &[String],
 ) -> bool {
-    // If the player is specified in the config then we will ignore all others.
-    if let Some(p) = preferred_player {
-        if !name.starts_with(&format!("org.mpris.MediaPlayer2.{}", p)) {
-            return true;
+    // If some players are specified in the config then we will ignore all others.
+    if !preferred_players.is_empty() {
+        if preferred_players
+            .iter()
+            .any(|player| name.starts_with(&format!("org.mpris.MediaPlayer2.{}", player)))
+        {
+            return false;
         }
+        return true;
     }
 
     if !name.starts_with("org.mpris.MediaPlayer2") {
